@@ -131,6 +131,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_apigateway
@@ -159,13 +161,13 @@ class ApiGatewayToSqs(
         allow_read_operation: typing.Optional[builtins.bool] = None,
         api_gateway_props: typing.Any = None,
         create_request_template: typing.Optional[builtins.str] = None,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         read_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -189,6 +191,10 @@ class ApiGatewayToSqs(
         :since: 0.8.0
         :summary: Constructs a new instance of the ApiGatewayToSqs class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToSqs.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = ApiGatewayToSqsProps(
             allow_create_operation=allow_create_operation,
             allow_delete_operation=allow_delete_operation,
@@ -266,13 +272,13 @@ class ApiGatewayToSqsProps:
         allow_read_operation: typing.Optional[builtins.bool] = None,
         api_gateway_props: typing.Any = None,
         create_request_template: typing.Optional[builtins.str] = None,
-        dead_letter_queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         delete_request_template: typing.Optional[builtins.str] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        log_group_props: typing.Optional[aws_cdk.aws_logs.LogGroupProps] = None,
+        log_group_props: typing.Optional[typing.Union[aws_cdk.aws_logs.LogGroupProps, typing.Dict[str, typing.Any]]] = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
-        queue_props: typing.Optional[aws_cdk.aws_sqs.QueueProps] = None,
+        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
         read_request_template: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -298,6 +304,21 @@ class ApiGatewayToSqsProps:
             log_group_props = aws_cdk.aws_logs.LogGroupProps(**log_group_props)
         if isinstance(queue_props, dict):
             queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(ApiGatewayToSqsProps.__init__)
+            check_type(argname="argument allow_create_operation", value=allow_create_operation, expected_type=type_hints["allow_create_operation"])
+            check_type(argname="argument allow_delete_operation", value=allow_delete_operation, expected_type=type_hints["allow_delete_operation"])
+            check_type(argname="argument allow_read_operation", value=allow_read_operation, expected_type=type_hints["allow_read_operation"])
+            check_type(argname="argument api_gateway_props", value=api_gateway_props, expected_type=type_hints["api_gateway_props"])
+            check_type(argname="argument create_request_template", value=create_request_template, expected_type=type_hints["create_request_template"])
+            check_type(argname="argument dead_letter_queue_props", value=dead_letter_queue_props, expected_type=type_hints["dead_letter_queue_props"])
+            check_type(argname="argument delete_request_template", value=delete_request_template, expected_type=type_hints["delete_request_template"])
+            check_type(argname="argument deploy_dead_letter_queue", value=deploy_dead_letter_queue, expected_type=type_hints["deploy_dead_letter_queue"])
+            check_type(argname="argument existing_queue_obj", value=existing_queue_obj, expected_type=type_hints["existing_queue_obj"])
+            check_type(argname="argument log_group_props", value=log_group_props, expected_type=type_hints["log_group_props"])
+            check_type(argname="argument max_receive_count", value=max_receive_count, expected_type=type_hints["max_receive_count"])
+            check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
+            check_type(argname="argument read_request_template", value=read_request_template, expected_type=type_hints["read_request_template"])
         self._values: typing.Dict[str, typing.Any] = {}
         if allow_create_operation is not None:
             self._values["allow_create_operation"] = allow_create_operation
